Learn R Programming

CALANGO (version 1.0.20)

install_bioc_dependencies: Install Bioconductor dependencies

Description

This function installs the latest versions of all Bioconductor packages required for the report generation, namely:

  • AnnotationDbi

  • KEGGREST

  • GO.db

Usage

install_bioc_dependencies(bioc.args = list(), force = FALSE)

Value

No return value, called for side effects.

Arguments

bioc.args

list containing further arguments to be passed down to `BiocManager::install()`.

force

logical: reinstall already-installed packages?

Details

It is essential that these Bioconductor packages be installed for CALANGO to work properly. It uses `BiocManager::install()` for installing Bioconductor packages. Further arguments to this function are passed as a list.

Examples

Run this code
if (FALSE) {
  install_bioc_dependencies()
}

Run the code above in your browser using DataLab