This function installs the latest versions of all Bioconductor packages
required for the report generation, namely:
AnnotationDbi
KEGGREST
GO.db
Usage
install_bioc_dependencies(bioc.args = list(), force = FALSE)
Value
No return value, called for side effects.
Arguments
bioc.args
list containing further arguments to be passed
down to `BiocManager::install()`.
force
logical: reinstall already-installed packages?
Details
It is essential that
these Bioconductor packages be installed for CALANGO to work properly.
It uses `BiocManager::install()` for installing Bioconductor
packages. Further arguments to this function are passed as a list.